import { ELEMENT_KEY } from '../../constants.js';
import { getBrowserObject } from '../../utils/index.js';
const getWebElement = (el) => ({
    [ELEMENT_KEY]: el.elementId,
    ELEMENT: el.elementId // jsonwp compatible
});
/**
 *
 * Return true if the selected element matches with the provided one.
 *
 * <example>
    :isEqual.js
    it('should detect if an element is clickable', async () => {
        const el = await $('#el')
        const sameEl = await $('#el')
        const anotherEl = await $('#anotherEl')

        el.isEqual(sameEl) // outputs: true

        el.isEqual(anotherEl) // outputs: false
    });
 * </example>
 *
 * @alias element.isEqual
 * @param   {Element}   el element to compare with
 * @return  {Boolean}   true if elements are equal
 *
 */
export async function isEqual(el) {
    const browser = getBrowserObject(this);
    // mobile native
    if (browser.isMobile) {
        const context = await browser.getContext();
        const contextId = typeof context === 'string'
            ? context
            : context?.id;
        if (contextId && contextId.toLowerCase().includes('native')) {
            return this.elementId === el.elementId;
        }
    }
    // browser or webview
    let result;
    try {
        result = await browser.execute(
        /* istanbul ignore next */
        function (el1, el2) { return el1 === el2; }, getWebElement(this), getWebElement(el));
    }
    catch (err) {
        result = false;
    }
    return result;
}
